function [x LB mu1 Mu phi duals time] = full_LP(F,integer,LP)
% LP-relaxation 
% F - hyperenergy1
% integer - if true solves ILP = global discrete optimum
% LP ['BLP','FLP'] default 'FLP' - two LP relaxations considered
% Output:
%  x - integer labeling (rounded solution)
%  LB - lower bound
%  mu1 - unary relaxed variables
%  Mu - all relaxed variables
%  phi - reparametrized unary terms
%  duals - all dual variables
% time - time spent in CPLEX

if ~exist('integer','var') || isempty(integer)
	integer = false;
end

if ~exist('LP','var') || isempty(LP)
	LP = 'FLP';
end

nV = get_nV(F);
nA = get_nA(F);
H = F.H;

A = get_LP(F,LP);
nvars = size(A,2);
const = 1;
mu = double(F.H.A>0);
n = nnz(mu);
mu(mu>0) = 1:n;

% constraints
lb = zeros(nvars,1);
ub = ones(nvars,1);
lb(const) = 1; ub(const) = 1;

% implement unary hard constraints
for v=1:nV
	[V x] = max(F.fA([1 2],v+1));
	if V>1e5 % forbidden entry
		ub(mu(x,v+1)) = 0;
	end
end

f = F.fA(H.A>0);

b_eq = zeros(size(A,1),1);

% check feasibility
x0 = zeros(1,nV);
mu0 = zeros(nvars,1);
for a=1:nA
	v = H.get_nodes(a);
	z = x0(v);
	Z = mbin2dec(num2str(z));
	mu0(mu(Z+1,a)) = 1;
end

assert(norm(A*mu0) < 1e-5);

tic
if exist('integer','var') && integer
	ops = cplexoptimset('lpmethod',0,'diagnostics','off','timelimit',1000); % automatic, 10 min time limit
	ops.mip.tolerances.integrality = 1e-7;
	ops.mip.tolerances.mipgap = 1e-6;
	ctype = repmat('B',1,nvars);
	[Mu,fval,exitflag,output] = cplexmilp(f,[],[],A,b_eq,[],[],[],lb,ub,ctype,[],ops);
	duals = [];
else
	% solve LP % CPLEX
	% 0 CPX_ALG_AUTOMATIC Automatic: let CPLEX choose; default
	% 1 CCPX_ALG_PRIMAL Primal simplex
	% 2 CPX_ALG_DUAL Dual simplex
	% 3 CPX_ALG_NET Network simplex
	% 4 CPX_ALG_BARRIER Barrier
	% 5 CPX_ALG_SIFTING Sifting
	% 6 CPX_ALG_CONCURRENT Concurrent (Dual, Barrier, and Primal)
	ops = cplexoptimset('lpmethod',0,'diagnostics','off');
	[Mu,fval,exitflag,output,lambda] = cplexlp(f,[],[],A,b_eq,lb,ub,mu0,ops);
	duals = lambda.eqlin;
end
time = toc;
%MU = mu;
%MU(mu>0) = Mu(:);

a = H.d==1;
mu1 = Mu(mu(1:2,a));
[ans x] = max(mu1,[],1); x = x-1;
LB = fval;
phi = [];

end